@@ -762,6 +762,7 @@ typedef enum {
     QEMU_MONITOR_MIGRATION_STATUS_POSTCOPY,
     QEMU_MONITOR_MIGRATION_STATUS_POSTCOPY_PAUSED,
     QEMU_MONITOR_MIGRATION_STATUS_POSTCOPY_RECOVER,
+    QEMU_MONITOR_MIGRATION_STATUS_POSTCOPY_RECOVER_SETUP,
     QEMU_MONITOR_MIGRATION_STATUS_COMPLETED,
     QEMU_MONITOR_MIGRATION_STATUS_ERROR,
     QEMU_MONITOR_MIGRATION_STATUS_CANCELLING,
@@ -814,6 +815,7 @@ struct _qemuMonitorMigrationStats {
     unsigned long long xbzrle_overflow;
 
     int cpu_throttle_percentage;
+    unsigned long long vfio_data_transferred;
 };
 
 int qemuMonitorGetMigrationStats(qemuMonitor *mon,
@@ -1210,8 +1212,8 @@ int qemuMonitorGetTPMTypes(qemuMonitor *mon,
                            char ***tpmtypes);
 
 int qemuMonitorAttachCharDev(qemuMonitor *mon,
-                             const char *chrID,
-                             virDomainChrSourceDef *chr);
+                             virJSONValue **props,
+                             char **ptypath);
 int qemuMonitorDetachCharDev(qemuMonitor *mon,
                              const char *chrID);
 
